@@ -679,12 +679,13 @@ fn inner_union(input: &DeriveInput, data: &DataUnion) -> Result<TokenStream2> {
         match format {
             None => {
                 display.push(quote_spanned! { field.span() =>
-                    Self::#type_name => f.write_str(#type_str),
+                    Self::#type_name => #type_str,
                 });
             }
             Some((format_str, format_alt)) => {
                 display.push(quote_spanned! { field.span() =>
-                    Self::#type_name => f.write_str(if !f.alternate() { #format_str } else { #format_alt }),
+                    Self::#type_name if !f.alternate() => #format_str,
+                    Self::#type_name => #format_alt,
                 });
             }
         }
@@ -697,18 +698,23 @@ fn inner_union(input: &DeriveInput, data: &DataUnion) -> Result<TokenStream2> {
                     .clone()
                     .into_token_stream2(&Fields::Unit, input.span(), false);
             let format_alt = tenchique.into_token_stream2(&Fields::Unit, input.span(), true);
-            quote! {
-                if f.alternate() {
-                    #format_alt
-                } else {
-                    #format_str
+            if format_str.to_string() != format_alt.to_string() {
+                quote! {
+                    if f.alternate() {
+                        #format_alt
+                    } else {
+                        #format_str
+                    }
                 }
+            } else {
+                quote! { #format_str }
             }
         }
         None => quote! {
-            match self {
+            let s = match self {
                 #( #display )*
-            }
+            };
+            f.write_str(s)
         },
     };
     Ok(quote! {
